@@ -63,12 +63,6 @@ from compas.datastructures.mesh.operations import mesh_split_edge
 from compas.datastructures.mesh.operations import mesh_unweld_vertices
 
 
-__author__     = 'Tom Van Mele'
-__copyright__  = 'Copyright 2014, Block Research Group - ETH Zurich'
-__license__    = 'MIT License'
-__email__      = '<vanmelet@ethz.ch>'
-
-
 TPL = """
 ================================================================================
 Mesh summary
@@ -153,7 +147,7 @@ class Mesh(FromToJson,
     # --------------------------------------------------------------------------
 
     def __str__(self):
-        """Compile a summary of the mesh."""
+        """Generate a readable representation of the data of the mesh."""
         return json.dumps(self.data, sort_keys=True, indent=4)
 
     def summary(self):
@@ -360,13 +354,15 @@ class Mesh(FromToJson,
     # --------------------------------------------------------------------------
 
     @classmethod
-    def from_obj(cls, filepath):
+    def from_obj(cls, filepath, precision=None):
         """Construct a mesh object from the data described in an OBJ file.
 
         Parameters
         ----------
         filepath : str
             The path to the file.
+        precision: str, optional
+            The precision of the geometric map that is used to connect the lines.
 
         Returns
         -------
@@ -391,7 +387,7 @@ class Mesh(FromToJson,
         >>> mesh = Mesh.from_obj(compas.get('faces.obj'))
 
         """
-        obj = OBJ(filepath)
+        obj = OBJ(filepath, precision)
         vertices = obj.parser.vertices
         faces    = obj.parser.faces
         edges    = obj.parser.lines
@@ -2371,6 +2367,49 @@ class Mesh(FromToJson,
 
         return vertices
 
+    def vertices_on_boundaries(self):
+        """Find the vertices on all boundaries of the mesh.
+
+        Returns
+        -------
+        list of list
+            A list of vertex keys per boundary.
+
+        Examples
+        --------
+        >>>
+
+        """
+        vertices_set = set()
+        for key, nbrs in iter(self.halfedge.items()):
+            for nbr, face in iter(nbrs.items()):
+                if face is None:
+                    vertices_set.add(key)
+                    vertices_set.add(nbr)
+
+        vertices_all = list(vertices_set)
+        boundaries = []
+
+        key = sorted([(key, self.vertex_coordinates(key)) for key in vertices_all], key=lambda x: (x[1][1], x[1][0]))[0][0]
+
+        while vertices_all:
+            vertices = []
+            start = key
+            while 1:
+                for nbr, fkey in iter(self.halfedge[key].items()):
+                    if fkey is None:
+                        vertices.append(nbr)
+                        key = nbr
+                        break
+                if key == start:
+                    boundaries.append(vertices)
+                    vertices_all = [x for x in vertices_all if x not in vertices]
+                    break
+            if vertices_all:
+                key = vertices_all[0]
+
+        return boundaries
+
     def faces_on_boundary(self):
         """Find the faces on the boundary.
 
@@ -2688,41 +2727,47 @@ if __name__ == '__main__':
     import compas
     from compas.plotters import MeshPlotter
 
-    # mesh = Mesh.from_obj(compas.get('faces.obj'))
+    mesh = Mesh.from_obj(compas.get('faces.obj'))
 
-    vertices = [
-        [0, 0, 0],
-        [1, 1, 0],
-        [1, -1, 0],
-        [-1, -1, 0],
-        [-1, 1, 0]
-    ]
-    faces = [
-        [0, 2, 1],
-        [0, 4, 3]
-    ]
+    # vertices = [
+    #     [0, 0, 0],
+    #     [1, 1, 0],
+    #     [1, -1, 0],
+    #     [-1, -1, 0],
+    #     [-1, 1, 0]
+    # ]
+    # faces = [
+    #     [0, 2, 1],
+    #     [0, 4, 3]
+    # ]
 
-    mesh = Mesh.from_vertices_and_faces(vertices, faces)
+    # mesh = Mesh.from_vertices_and_faces(vertices, faces)
 
-    print(mesh.is_manifold())
+    # print(mesh.is_manifold())
 
-    # mesh = Mesh()
+    # # mesh = Mesh()
 
-    # a = mesh.add_vertex(x=0, y=0)
-    # b = mesh.add_vertex(x=0.5, y=0.1)
-    # c = mesh.add_vertex(x=1, y=0)
-    # d = mesh.add_vertex(x=0.9, y=0.5)
-    # e = mesh.add_vertex(x=0.9, y=1)
-    # f = mesh.add_vertex(x=0.5, y=1)
-    # g = mesh.add_vertex(x=0, y=1)
-    # h = mesh.add_vertex(x=0, y=0.5)
+    # # a = mesh.add_vertex(x=0, y=0)
+    # # b = mesh.add_vertex(x=0.5, y=0.1)
+    # # c = mesh.add_vertex(x=1, y=0)
+    # # d = mesh.add_vertex(x=0.9, y=0.5)
+    # # e = mesh.add_vertex(x=0.9, y=1)
+    # # f = mesh.add_vertex(x=0.5, y=1)
+    # # g = mesh.add_vertex(x=0, y=1)
+    # # h = mesh.add_vertex(x=0, y=0.5)
 
-    # mesh.add_face([a, b, c, d, e, f, g, h])
+    # # mesh.add_face([a, b, c, d, e, f, g, h])
 
-    plotter = MeshPlotter(mesh)
+    # plotter = MeshPlotter(mesh)
 
-    plotter.draw_vertices()
-    plotter.draw_edges()
-    plotter.draw_faces()
+    # plotter.draw_vertices()
+    # plotter.draw_edges()
+    # plotter.draw_faces()
 
-    plotter.show()
+    # plotter.show()
+
+    print(mesh.get_vertices_attribute('x'))
+    print(mesh.get_vertices_attributes('xy'))
+
+    print(mesh.get_edges_attribute('q', 1.0))
+    print(mesh.get_edges_attributes('qf', (1.0, 2.0)))
