@@ -23,21 +23,8 @@ try:
 except ImportError:
     compas.raise_if_not_ironpython()
 
-    # try:
-    #     from System.Diagnostics import Process
 
-    # except ImportError:
-    #     compas.raise_if_ironpython()
-
-
-
-__author__     = ['Tom Van Mele', ]
-__copyright__  = 'Copyright 2014, Block Research Group - ETH Zurich'
-__license__    = 'MIT License'
-__email__      = 'vanmelet@ethz.ch'
-
-
-__all__ = ['XFunc', ]
+__all__ = ['XFunc']
 
 
 WRAPPER = """
@@ -205,7 +192,7 @@ class XFunc(object):
         import compas
         import compas_rhino
 
-        from compas_rhino.helpers import MeshArtist
+        from compas_rhino.artists import MeshArtist
         from compas.datastructures import Mesh
         from compas.utilities import XFunc
 
