@@ -19,13 +19,7 @@ except ImportError:
     compas.raise_if_ironpython()
 
 
-__author__     = ['Tom Van Mele', ]
-__copyright__  = 'Copyright 2017, BLOCK Research Group - ETH Zurich'
-__license__    = 'MIT License'
-__email__      = 'vanmelet@ethz.ch'
-
-
-__all__ = ['RhinoCurve', ]
+__all__ = ['RhinoCurve']
 
 
 class RhinoCurve(RhinoGeometry):
